\name{districtwiseApp}

\alias{districtwiseApp}

\title{Adapter module for districtwise apportionment using BAZI}

\description{Computes a districtwise Apportionment}

\usage{
districtwiseApp(districtMagnitudes, votes, appMethod="DivStd", pq=NULL,
                minConstr=NA, maxConstr= NA, directSeats = NA, listCombination = NA,
                sorting = "app", printDistr = FALSE, name = NULL)}

\arguments{
	\item{districtMagnitudes}{Number of seats to be apportioned in the districts}
	\item{votes}{Matrix with input weights, e.g. votes for parties}
	\item{appMethod}{Rounding method(s) to be used for apportionment: one of
		\code{"DivDwn", "DivStd", "DivGeo", "DivHar", "DivUp", "DivSta", "DivPMean",
		"HaQgrR"} or \code{"DrQgrR"}}
	\item{pq}{\eqn{\in [0,1]}{in [0,1]} for stationary rounding \code{"DivSta"},
		\eqn{\in R}{in R} for power means rounding \code{"DivPMean"}}
	\item{minConstr}{Matrix of minimum requirements, forces \code{apporitonment >= minConstr}}
	\item{maxConstr}{Matrix of maximum constraints, forces \code{apportionmen <= maxConstr}}
	\item{directSeats}{Matrix of direct seats for mixed member systems}
	\item{listCombination}{Matrix indicating belonging to a list combination, $0$ 
		indicates not member of a list combination}	
	\item{sorting}{Sort parties in decreasing order of number of votes}
	\item{printDistr}{Indicator to include the apportionment for each district}
	\item{name}{Name for the apportionment problem}
}

\details{
For the \kbd{appMethod} argument the different following rounding methods are valid:
rounding down (\code{"DivDwn"}) to the last integer, standard rounding 
(\code{"DivStd"}) in the "usual way", geometric rounding (\code{"DivGeo"}),
harmonic rounding (\code{"DivHar"}), rounding up (\code{"DivUp"}) to the next
integer, general stationary rounding (\code{"DivSta"}), and power means
rounding (\code{"DivPMean"}). Additionaly, there are two quota methods
implemented: Hare quota with greatest remainders (\code{"HaQgrR"}) and
Droop quota with greates remainders (\code{"DrQgrR"})
}

\value{
A list with components
	\item{votes}{input votes (sorted) and then recursive}
	\item{apportionment}{}
	\item{ties}{}
	\item{pt}{}
}

\seealso{\code{\link{computeApportionment}}}

\references{
	\url{http://www.uni-augsburg.de/bazi}.
	
	Maier, S. and Pukelsheim, F. (2007) \emph{BAZI - A Free Program for Proportional
	Representation Apportionment}, Preprint No. 42, Institute for Mathematics, 
	University of Augsburg.
}	

\keyword{math}
